@@ -21,8 +21,8 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.000';
-# This file is part of Finance-PaycheckRecords 1.000 (July 5, 2014)
+our $VERSION = '1.001';
+# This file is part of Finance-PaycheckRecords 1.001 (October 24, 2015)
 
 use Carp qw(croak);
 use HTML::TableExtract 2.10;
@@ -193,8 +193,8 @@ Finance::PaycheckRecords - Parse data from PaycheckRecords.com
 
 =head1 VERSION
 
-This document describes version 1.000 of
-Finance::PaycheckRecords, released July 5, 2014.
+This document describes version 1.001 of
+Finance::PaycheckRecords, released October 24, 2015.
 
 =head1 SYNOPSIS
 
@@ -371,8 +371,8 @@ deposit amount (default C<Net This Check>).
 
 =back
 
-The F<example> directory in this distribution contains a sample
-paystub along with a program to generate a complete QIF file from it.
+The F<example> directory in this distribution contains sample
+paystubs along with a program to generate a complete QIF file from one.
 
 =head1 SEE ALSO
 
@@ -397,8 +397,9 @@ None reported.
 =head1 BUGS AND LIMITATIONS
 
 I don't know how consistent the layout of paystubs for different
-companies are.  An example paystub is included as
-F<example/Paycheck-2013-01-04.html>.
+companies are.  Two example paystubs are included as
+F<example/Paycheck-2013-01-04.html> (printed check) and
+F<example/Paycheck-2015-10-23.html> (direct deposit).
 
 If your paystub doesn't parse properly, please report a bug (see the
 AUTHOR section) and attach a copy of one of your paystubs (after
@@ -419,7 +420,7 @@ L<< https://github.com/madsen/finance-paycheckrecords >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
